==> react-redux-datatable-2.0.1.tgz: package/README.md <==
# react-redux-datatable

[![Build Status](https://travis-ci.org/sean-ww/react-redux-datatable.svg?branch=master)](https://travis-ci.org/sean-ww/react-redux-datatable)
[![Coverage Status](https://coveralls.io/repos/github/sean-ww/react-redux-datatable/badge.svg?branch=master)](https://coveralls.io/github/sean-ww/react-redux-datatable?branch=master)
[![Version](https://img.shields.io/npm/v/react-redux-datatable.svg)](https://www.npmjs.org/package/react-redux-datatable)
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/sean-ww/react-redux-datatable/master/LICENSE)

Dynamic data table using React and Redux that fetches JSON from a predefined API. Designed to build asynchronous React-Redux tables quickly and consistently.

![Example](react-redux-datatable.png)

#### Version 2 / React 16
Version 2 works with React 16 builds upon [react-bootstrap-table2](https://github.com/react-bootstrap-table/react-bootstrap-table2).
* Filter and search data by text or by column values
* Built in ability to filter date ranges, number, text and select lists
* Paginate and Sort data
* Configurable table and column widths
* Ability to add custom filters and column formatters
* Optional local storage of filter data
* Uses React and Redux with a predefined API
* Add table headers
* Toggle full screen view
* Export to csv

#### Version 1 / React < 16
Version 1 supports older versions of react and uses [react-bootstrap-table](https://github.com/AllenFang/react-bootstrap-table).

### Demo

[View the Demo](http://seanwallis.com/datatable-demo/)

### Documentation

[You will find full documentation here](https://sean-ww.github.io/react-redux-datatable)

### Contributing

See the [Contributors Guide](https://github.com/sean-ww/react-datatable/blob/master/CONTRIBUTING.md)

### License

The MIT License (MIT). Please view the [License File](https://github.com/sean-ww/react-datatable/blob/master/LICENSE) for more information.

==> react-redux-datatable-2.1.3.tgz: package/README.md <==
# react-redux-datatable

[![Build Status](https://travis-ci.org/sean-ww/react-redux-datatable.svg?branch=master)](https://travis-ci.org/sean-ww/react-redux-datatable)
[![Coverage Status](https://coveralls.io/repos/github/sean-ww/react-redux-datatable/badge.svg?branch=master)](https://coveralls.io/github/sean-ww/react-redux-datatable?branch=master)
[![Version](https://img.shields.io/npm/v/react-redux-datatable.svg)](https://www.npmjs.org/package/react-redux-datatable)
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/sean-ww/react-redux-datatable/master/LICENSE)

Dynamic data table using React and Redux that fetches JSON from a predefined API. Designed to build asynchronous React-Redux tables quickly and consistently.

![Example](https://github.com/sean-ww/react-redux-datatable/raw/master/react-redux-datatable.png)

* Filter column values by date ranges, number, text and select lists
* Paginate and Sort data
* Configurable table and column widths
* Ability to add custom filters and column formatters
* Optional local storage of filter data
* Uses React and Redux with a predefined API
* Add table headers
* Toggle full screen view
* Export to csv

### Demo

[View the Demo](https://sean-ww.github.io/react-redux-datatable/demo)

### Documentation

[You will find full documentation here](https://sean-ww.github.io/react-redux-datatable)

### Contributing

See the [Contributors Guide](https://github.com/sean-ww/react-datatable/blob/master/CONTRIBUTING.md)

### License

The MIT License (MIT). Please view the [License File](https://github.com/sean-ww/react-datatable/blob/master/LICENSE) for more information.
